==> apache-yunikorn-1.1.0-src.tar.gz: apache-yunikorn-1.1.0-src/web/src/app/components/app-history/app-history.component.spec.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { async, ComponentFixture, TestBed } from '@angular/core/testing';
import { MatCardModule } from '@angular/material/card';
import { configureTestSuite } from 'ng-bullet';
import { MockComponent } from 'ng-mocks';

import { AppHistoryComponent } from './app-history.component';
import { AreaChartComponent } from '@app/components/area-chart/area-chart.component';

describe('AppHistoryComponent', () => {
  let component: AppHistoryComponent;
  let fixture: ComponentFixture<AppHistoryComponent>;

  configureTestSuite(() => {
    TestBed.configureTestingModule({
      declarations: [AppHistoryComponent, MockComponent(AreaChartComponent)],
      imports: [MatCardModule],
    });
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(AppHistoryComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create the component', () => {
    expect(component).toBeTruthy();
  });
});

==> apache-yunikorn-1.5.2-src.tar.gz: apache-yunikorn-1.5.2-src/web/src/app/components/app-history/app-history.component.spec.ts <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {ComponentFixture, TestBed} from '@angular/core/testing';
import {MatCardModule} from '@angular/material/card';
import {AreaChartComponent} from '@app/components/area-chart/area-chart.component';
import {MockComponent} from 'ng-mocks';

import {AppHistoryComponent} from './app-history.component';

describe('AppHistoryComponent', () => {
  let component: AppHistoryComponent;
  let fixture: ComponentFixture<AppHistoryComponent>;

  beforeAll(() => {
    TestBed.configureTestingModule({
      declarations: [AppHistoryComponent, MockComponent(AreaChartComponent)],
      imports: [MatCardModule],
    }).compileComponents();
  });

  beforeEach(() => {
    fixture = TestBed.createComponent(AppHistoryComponent);
    component = fixture.componentInstance;
    fixture.detectChanges();
  });

  it('should create the component', () => {
    expect(component).toBeTruthy();
  });
});
